==> assemble-goldcome-highlight-0.0.1.tgz: package/Gruntfile.js <==
/*
 * Assemble Plugin: toc
 * https://bitbucket.org/goldcome/assemble-goldcome-toc
 *
 * Copyright (c) 2014 GoldCome, contributors
 * Licensed under the MIT license.
 */

'use strict';

module.exports = function (grunt) {

    // Project configuration.
    grunt.initConfig({

        pkg: grunt.file.readJSON('package.json'),

        jshint: {
            options: {
                curly: true,
                eqeqeq: true,
                immed: true,
                latedef: true,
                newcap: true,
                noarg: true,
                sub: true,
                undef: true,
                boss: true,
                eqnull: true,
                node: true
            },
            all: ['Gruntfile.js', 'index.js']
        },

        assemble: {
            options: {
                assets: 'test/assets',
                plugins: ['./index.js'],
                layoutdir: 'test/fixtures/layouts',
                layoutext: '.hbs',
                layout: 'default'
            },
            hightlight: {
                files: [
                    {
                        expand: true,
                        cwd: 'test/fixtures/pages',
                        src: ['**/*.hbs'],
                        dest: 'test/actual/hightlight'
                    }
                ]
            },
            hightlight_option: {
                options: {
                    highlight: {
                        boxid: 'hightlight-content'
                    }
                },
                files: [
                    {
                        expand: true,
                        cwd: 'test/fixtures/pages',
                        src: ['**/*.hbs'],
                        dest: 'test/actual/hightlight_option'
                    }
                ]
            }
        },

        // Before generating new files, remove any files from previous build.
        clean: {
            actual: ['test/actual/**']
        },

        //Start a server
        connect: {
            server: {
                options: {
                    port: 9000,
                    base: '.',
                    keepalive: true
                }
            }
        }
    });

    // These plugins provide necessary tasks.
    grunt.loadNpmTasks('assemble');
    grunt.loadNpmTasks('grunt-readme');
    grunt.loadNpmTasks('grunt-contrib-clean');
    grunt.loadNpmTasks('grunt-contrib-jshint');
    grunt.loadNpmTasks('grunt-contrib-connect');

    // By default, lint and run all tests.
    grunt.registerTask('default', ['jshint', 'clean', 'assemble']);
};

==> assemble-goldcome-highlight-0.0.2.tgz: package/Gruntfile.js <==
/*
 * Assemble Plugin: toc
 * https://bitbucket.org/goldcome/assemble-goldcome-toc
 *
 * Copyright (c) 2014 GoldCome, contributors
 * Licensed under the MIT license.
 */

'use strict';

module.exports = function (grunt) {

    // Project configuration.
    grunt.initConfig({

        pkg: grunt.file.readJSON('package.json'),

        jshint: {
            options: {
                curly: true,
                eqeqeq: true,
                immed: true,
                latedef: true,
                newcap: true,
                noarg: true,
                sub: true,
                undef: true,
                boss: true,
                eqnull: true,
                node: true
            },
            all: ['Gruntfile.js', 'index.js']
        },

        assemble: {
            options: {
                assets: 'test/assets',
                plugins: ['./index.js'],
                layoutdir: 'test/fixtures/layouts',
                layoutext: '.hbs',
                layout: 'default'
            },
            hightlight: {
                files: [
                    {
                        expand: true,
                        cwd: 'test/fixtures/pages',
                        src: ['**/*.hbs'],
                        dest: 'test/actual/hightlight'
                    }
                ]
            },
            hightlight_option: {
                options: {
                    highlight: {
                        boxid: 'hightlight-content',
                        selector: 'precode'
                    }
                },
                files: [
                    {
                        expand: true,
                        cwd: 'test/fixtures/pages',
                        src: ['**/*.hbs'],
                        dest: 'test/actual/hightlight_option'
                    }
                ]
            }
        },

        // Before generating new files, remove any files from previous build.
        clean: {
            actual: ['test/actual/**']
        },

        //Start a server
        connect: {
            server: {
                options: {
                    port: 9000,
                    base: '.',
                    keepalive: true
                }
            }
        }
    });

    // These plugins provide necessary tasks.
    grunt.loadNpmTasks('assemble');
    grunt.loadNpmTasks('grunt-readme');
    grunt.loadNpmTasks('grunt-contrib-clean');
    grunt.loadNpmTasks('grunt-contrib-jshint');
    grunt.loadNpmTasks('grunt-contrib-connect');

    // By default, lint and run all tests.
    grunt.registerTask('default', ['jshint', 'clean', 'assemble']);
};
